.. Pacifica Ingest documentation master file, created by
   sphinx-quickstart on Thu Dec  6 20:05:08 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Pacifica Ingest's documentation!
=============================================

The Pacifica Ingest service provides endpoints to consume data and
metadata for ingest into Pacifica.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   configuration
   exampleusage
   ingest

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
